==> autokreso-mailchimp-0.1.0-0751b2.tar: test/Entity/MailingList/CampaignDefaultsTest.php <==
<?php
namespace AkTest\Mailchimp\Entity\MailingList;

use Ak\Mailchimp\Entity\MailingList\CampaignDefaults;
use AkTest\Mailchimp\AbstractTestCase;
use Zend\Hydrator\HydratorInterface;
use Zend\Hydrator\HydratorPluginManager;
use Zend\ServiceManager\PluginManagerInterface;

/**
 * Class MailingListCampaignDefaultsTest
 *
 * @package AkTest\Mailchimp\Entity\MailingList
 * @author Danijel Fabijan <hipnaba@gmail.com>
 * @link https://bitbucket.org/autokreso/mailchimp
 */
final class
CampaignDefaultsTest extends AbstractTestCase
{
    public function testHydratorCanExchangeEntity()
    {
        $container = $this->getContainer();
        /** @var PluginManagerInterface $hydrators */
        $hydrators = $container->get(HydratorPluginManager::class);
        /** @var HydratorInterface $hydrator */
        $hydrator = $hydrators->get(CampaignDefaults::class);

        $data = [
            'from_name' => 'Neko ime',
            'from_email' => 'korisnik@domena.tld',
            'subject' => 'Predmet',
            'language' => 'hrvatski',
        ];

        /** @var CampaignDefaults $defaults */
        $defaults = $hydrator->hydrate($data, new CampaignDefaults());

        $this->assertEquals($data['from_name'], $defaults->getFromName());
        $this->assertEquals($data['from_email'], $defaults->getFromEmail());
        $this->assertEquals($data['subject'], $defaults->getSubject());
        $this->assertEquals($data['language'], $defaults->getLanguage());

        $extracted = $hydrator->extract($defaults);

        $this->assertEquals($data, $extracted);
    }
}

==> autokreso-mailchimp-0.1.4-44891a.tar: test/Entity/MailingList/CampaignDefaultsTest.php <==
<?php
namespace AkTest\Mailchimp\Entity\MailingList;

use Ak\Mailchimp\Entity\MailingList\CampaignDefaults;
use AkTest\Mailchimp\AbstractTestCase;
use Laminas\Hydrator\HydratorInterface;
use Laminas\Hydrator\HydratorPluginManager;
use Laminas\ServiceManager\PluginManagerInterface;

/**
 * Class MailingListCampaignDefaultsTest
 *
 * @package AkTest\Mailchimp\Entity\MailingList
 * @author Danijel Fabijan <hipnaba@gmail.com>
 * @link https://bitbucket.org/autokreso/mailchimp
 */
final class
CampaignDefaultsTest extends AbstractTestCase
{
    public function testHydratorCanExchangeEntity()
    {
        $container = $this->getContainer();
        /** @var PluginManagerInterface $hydrators */
        $hydrators = $container->get(HydratorPluginManager::class);
        /** @var HydratorInterface $hydrator */
        $hydrator = $hydrators->get(CampaignDefaults::class);

        $data = [
            'from_name' => 'Neko ime',
            'from_email' => 'korisnik@domena.tld',
            'subject' => 'Predmet',
            'language' => 'hrvatski',
        ];

        /** @var CampaignDefaults $defaults */
        $defaults = $hydrator->hydrate($data, new CampaignDefaults());

        $this->assertEquals($data['from_name'], $defaults->getFromName());
        $this->assertEquals($data['from_email'], $defaults->getFromEmail());
        $this->assertEquals($data['subject'], $defaults->getSubject());
        $this->assertEquals($data['language'], $defaults->getLanguage());

        $extracted = $hydrator->extract($defaults);

        $this->assertEquals($data, $extracted);
    }
}
